sample_model_parameters: Function to Sample Model Parameters

Description Usage Arguments Value See Also Examples

View source: R/sample_model_parameters.R

Description

The serial interval is estimated as 1.44 (95 this study. Samples were taken by assuming a normal distribution with a standard deviation estimated from the parameters confidence intervals. The above study includes data on the percentage of cases in each year since infection in the form of a figure. This appears to roughly match the original model estimate. As no other estimate is available the point estimate from the original model is used.

Usage

1
2
3
sample_model_parameters(incidence_rates = sutherland_incidence_rates,
  population_data = sutherland_data, samples = 100,
  as_sutherland = FALSE)

Arguments

incidence_rates

Incidence rates as formated by sutherland_incidence_rates

population_data

Population data as formated by sutherland_data

samples

Numeric, the number of samples to run. Defaults to 100

as_sutherland

Logical, defaults to FALSE. If TRUE then the original estimates used by sutherland et al. are returned. Note these are point estimates.

Value

A tibble of parameter samples

See Also

sample_incidence_rates

Examples

1

seabbs/AssessBCGPolicyChange documentation built on Dec. 24, 2019, 11:56 a.m.