simulate_sutherland_model: Function to run multiple simulations of the Sutherland et al....

Description Usage Arguments Value Examples

View source: R/simulate_sutherland_model.R

Description

Function to run multiple simulations of the Sutherland et al. Estimation Model

Usage

1
2
3
4
5
  simulate_sutherland_model(list_annual_TB_decrease = list(TB_decrease_as_matrix(sutherland_TB_decrease),
  TB_decrease_as_matrix(sutherland_TB_decrease)),
  list_incidence_rates = list(sutherland_incidence_rates,
  sutherland_incidence_rates), list_percentage_year_one = rep(0.764, 2),
  list_sym_lag = list(2, 2), cores = 1, ...)

Arguments

list_annual_TB_decrease

A list of annual TB decreases with each element as specified for the Annual.TB.Decrease.Yearly arguement of sutherland_model.

list_incidence_rates

A list of incidence rates with each element as specified for the incidence_rates arguement of sutherland_model.

list_percentage_year_one

A list of percentage secondary notifications in the first year with each element as specified for the Percentage.Year.One arguement of sutherland_model.

cores

The number of cores to use, defaults to one

...

Additional parameters to pass to sutherland_model.

Value

A list of simulations for each of the outputs of sutherland_model.

Examples

1

seabbs/AssessBCGPolicyChange documentation built on Dec. 24, 2019, 11:56 a.m.