Description Usage Arguments Value See Also Examples
View source: R/sample_model_parameters.R
The serial interval is estimated as 1.44 (95 this study. Samples were taken by assuming a normal distribution with a standard deviation estimated from the parameters confidence intervals. The above study includes data on the percentage of cases in each year since infection in the form of a figure. This appears to roughly match the original model estimate. As no other estimate is available the point estimate from the original model is used.
1 2 3 | sample_model_parameters(incidence_rates = sutherland_incidence_rates,
population_data = sutherland_data, samples = 100,
as_sutherland = FALSE)
|
incidence_rates |
Incidence rates as formated by |
population_data |
Population data as formated by |
samples |
Numeric, the number of samples to run. Defaults to 100 |
as_sutherland |
Logical, defaults to |
A tibble of parameter samples
sample_incidence_rates
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.