Description Usage Arguments Value Examples
View source: R/simulate_sutherland_model.R
Function to run multiple simulations of the Sutherland et al. Estimation Model
1 2 3 4 5 | simulate_sutherland_model(list_annual_TB_decrease = list(TB_decrease_as_matrix(sutherland_TB_decrease),
TB_decrease_as_matrix(sutherland_TB_decrease)),
list_incidence_rates = list(sutherland_incidence_rates,
sutherland_incidence_rates), list_percentage_year_one = rep(0.764, 2),
list_sym_lag = list(2, 2), cores = 1, ...)
|
list_annual_TB_decrease |
A list of annual TB decreases with each element as specified for
the |
list_incidence_rates |
A list of incidence rates with each element as specified for the |
list_percentage_year_one |
A list of percentage secondary notifications in the first year
with each element as specified for the |
cores |
The number of cores to use, defaults to one |
... |
Additional parameters to pass to |
A list of simulations for each of the outputs of sutherland_model.
1 | simulate_sutherland_model(cores = 1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.